/*
 * ========================================================================
 *
 * Codehaus CARGO, copyright 2004-2011 Vincent Massol.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * ========================================================================
 */
package org.codehaus.cargo.container.jboss;

import java.io.File;

import org.codehaus.cargo.container.configuration.LocalConfiguration;
import org.codehaus.cargo.container.spi.jvm.JvmLauncher;

/**
 * JBoss 6.1.x series container implementation.
 * 
 * @version $Id: JBoss61xInstalledLocalContainer.java 3657 2013-05-26 21:49:15Z alitokmen $
 */
public class JBoss61xInstalledLocalContainer extends JBoss6xInstalledLocalContainer
{
    /**
     * JBoss 6.1.x series unique id.
     */
    private static final String ID = "jboss61x";

    /**
     * {@inheritDoc}
     * @see JBoss6xInstalledLocalContainer#JBoss6xInstalledLocalContainer(org.codehaus.cargo.container.configuration.LocalConfiguration)
     */
    public JBoss61xInstalledLocalContainer(LocalConfiguration configuration)
    {
        super(configuration);
    }

    /**
     * {@inheritDoc}
     * @see org.codehaus.cargo.container.Container#getId()
     */
    public String getId()
    {
        return ID;
    }

    /**
     * {@inheritDoc}
     * @see org.codehaus.cargo.container.Container#getName()
     */
    public String getName()
    {
        return "JBoss " + getVersion("6.1.x");
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void doStart(JvmLauncher java) throws Exception
    {
        String loggingPropertiesFile = getFileHandler().append(
            getHome(), "bin/logging.properties");
        java.setSystemProperty("logging.configuration",
            new File(loggingPropertiesFile).toURI().toURL().toString());
        super.doStart(java);
    }

}
